@@ -10,7 +10,7 @@ use vars qw($VERSION);
 
 my $format = '%#:%m%d';
 
-$VERSION = '1.17';
+$VERSION = '1.18';
 
 # Lifted from Date::Holidays::DE example: feiertage.pl
 # Ref: https://metacpan.org/source/MSCHMITT/Date-Holidays-DE-1.9/example/feiertage.pl
@@ -55,9 +55,6 @@ sub holidays {
 
     my $state = $params{'state'} ? $params{'state'} : ['all'];
 
-    use Data::Dumper;
-    print STDERR "We got state: ", Dumper $state;
-
     my $holidays;
 
     if ( $params{'year'} ) {
@@ -115,8 +112,6 @@ sub _transform_arrayref_to_hashref {
         $hashref_of_holidays->{$key} = $holiday_names{$shortname};
     }
 
-    print STDERR "We got state: ", Dumper $hashref_of_holidays;
-
     return $hashref_of_holidays;
 }
 
@@ -132,7 +127,7 @@ Date::Holidays::Adapter::DE - an adapter class for Date::Holidays::DE
 
 =head1 VERSION
 
-This POD describes version 1.17 of Date::Holidays::Adapter::DE
+This POD describes version 1.18 of Date::Holidays::Adapter::DE
 
 =head1 DESCRIPTION
 
@@ -163,7 +158,7 @@ B<countrycode> in the call to the constructor B<new>.
 The calendar will spand for a year and the keys consist of B<month> and B<day>
 concatenated.
 
-In addition from version 1.17 the adapter support the B<state> parameter, defaulting to
+In addition from version 1.18 the adapter support the B<state> parameter, defaulting to
 B<'all'>.
 
 =head1 DIAGNOSTICS
